# gozerbot package
#
#

""" gozerbot core package. """

__copyright__ = 'this file is in the public domain'

__version__ = "0.9.2"

__all__ = ['aliases', 'database', 'ignore', 'periodical', 'tests', \
'botbase',  'datadir', 'persist', 'threads', \
'cache', 'eventbase', 'irc', 'plughelp', 'users', \
'callbacks', 'eventhandler', 'jabber', 'plugins', 'utils', \
'channels', 'examples', 'jsonusers', 'plugs', 'wait', \
'commands', 'exit', 'less', 'redispatcher', \
'compat', 'fleet', 'monitor', 'rest', \
'config', 'morphs', 'runner', 'wave', \
'contrib', 'gozerimport', 'partyline', 'stats', 'utils', 'reboot', 'xmpp']

# ==============
# IMPORT SECTION

from eggs import loadegg
import os

# END IMPORT
# ==========

# ============
# LOCK SECTION

# no locks

# END LOCK
# ========

# ============
# INIT SECTION

loadegg('simplejson', [os.getcwd(), os.getcwd() + os.sep + 'gozernest'], log=False)
loadegg('sqlalchemy', [os.getcwd(), os.getcwd() + os.sep + 'gozernest'], log=False)

# END INIT
# ========